@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"runtime"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/engine"
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 	"github.com/spf13/cobra"
@@ -19,12 +20,7 @@ var upgradeCmd = &cobra.Command{
 	Args:  cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
 		if runtime.GOOS == platform.LINUX {
-			fmt.Print("\n    ⚠️ upgrade is not supported on this platform\n\n")
-			return
-		}
-
-		if force {
-			upgrade.Run()
+			fmt.Print("\n⚠️ upgrade is not supported on this platform\n\n")
 			return
 		}
 
@@ -34,12 +30,21 @@ var upgradeCmd = &cobra.Command{
 		env.Init()
 		defer env.Close()
 
-		if _, hasNotice := upgrade.Notice(env, true); !hasNotice {
-			fmt.Print("\n    ✅  no new version available\n\n")
+		if force {
+			upgrade.Run(env)
 			return
 		}
 
-		upgrade.Run()
+		cfg := engine.LoadConfig(env)
+
+		if _, hasNotice := upgrade.Notice(env, true); !hasNotice {
+			if !cfg.DisableNotice {
+				fmt.Print("\n✅  no new version available\n\n")
+			}
+			return
+		}
+
+		upgrade.Run(env)
 	},
 }
 
