@@ -7,15 +7,29 @@ import (
 	"bytes"
 	"io"
 	"path"
+	"runtime"
 	"strings"
+
+	"github.com/jandedobbeleer/oh-my-posh/src/platform"
+	"github.com/jandedobbeleer/oh-my-posh/src/platform/cmd"
 )
 
-func InstallZIP(data []byte, user bool) error {
+func contains[S ~[]E, E comparable](s S, e E) bool {
+	for _, a := range s {
+		if a == e {
+			return true
+		}
+	}
+	return false
+}
+
+func InstallZIP(data []byte, user bool) ([]string, error) {
+	var families []string
 	bytesReader := bytes.NewReader(data)
 
 	zipReader, err := zip.NewReader(bytesReader, int64(bytesReader.Len()))
 	if err != nil {
-		return err
+		return families, err
 	}
 
 	fonts := make(map[string]*Font)
@@ -23,16 +37,16 @@ func InstallZIP(data []byte, user bool) error {
 	for _, zf := range zipReader.File {
 		rc, err := zf.Open()
 		if err != nil {
-			return err
+			return families, err
 		}
 		defer rc.Close()
 
 		data, err := io.ReadAll(rc)
 		if err != nil {
-			return err
+			return families, err
 		}
 
-		fontData, err := newFont(zf.Name, data)
+		fontData, err := newFont(path.Base(zf.Name), data)
 		if err != nil {
 			continue
 		}
@@ -51,9 +65,18 @@ func InstallZIP(data []byte, user bool) error {
 
 	for _, font := range fonts {
 		if err = install(font, user); err != nil {
-			return err
+			return families, err
+		}
+
+		if !contains(families, font.Family) {
+			families = append(families, font.Family)
 		}
 	}
 
-	return nil
+	// Update the font cache when installing fonts on Linux
+	if runtime.GOOS == platform.LINUX || runtime.GOOS == platform.DARWIN {
+		_, _ = cmd.Run("fc-cache", "-f")
+	}
+
+	return families, nil
 }
